@@ -50,9 +50,9 @@
 #' ## ------------------------------------------------------------
 #' ## ------------- iris data
 #' ## You can build a randomForest
-#' rfsrc_iris <- rfsrc(Species ~ ., data = iris)
+#' # rfsrc_iris <- rfsrc(Species ~ ., data = iris)
 #' # ... or load a cached randomForestSRC object
-#' # data(rfsrc_iris, package="ggRandomForests")
+#' data(rfsrc_iris, package="ggRandomForests")
 #'
 #' # Get a data.frame containing error rates
 #' gg_dta<- gg_error(rfsrc_iris)
@@ -73,7 +73,7 @@
 #' # Plot the gg_error object
 #' plot(gg_dta)
 #' }
-#'\dontrun{
+#'
 #' ## ------------- Boston data
 #' data(rfsrc_Boston, package="ggRandomForests")
 #'
@@ -82,7 +82,7 @@
 #'
 #' # Plot the gg_error object
 #' plot(gg_dta)
-#'}
+#'
 #' \dontrun{
 #' ## ------------- mtcars data
 #'
@@ -104,15 +104,17 @@
 #'
 #' gg_dta <- gg_error(rfsrc_veteran)
 #' plot(gg_dta)
-#' }
-#'\dontrun{
+#' 
 #' ## ------------- pbc data
 #' # Load a cached randomForestSRC object
 #' data(rfsrc_pbc, package="ggRandomForests")
 #'
 #' gg_dta <- gg_error(rfsrc_pbc)
 #' plot(gg_dta)
-#'}
+#' }
+#' 
+#' @importFrom stats na.omit
+#' 
 #' @export gg_error gg_error.rfsrc gg_error.randomForest gg_error.randomForest.formula
 gg_error <- function (object, ...) {
   UseMethod("gg_error", object)
@@ -146,7 +148,7 @@ gg_error.rfsrc <- function(object, ...) {
                       membership=FALSE)
     gg_dta$train <- gg_prd$err.rate
   }
-  
+  gg_dta <- na.omit(gg_dta)
   class(gg_dta) <- c("gg_error",class(gg_dta))
   invisible(gg_dta)
 }
