@@ -43,7 +43,7 @@
 #' Regression and Classification (RF-SRC), R package version 1.4.
 #' 
 #' @importFrom ggplot2 ggplot aes_string geom_point geom_smooth labs element_text
-#' @importFrom tidyr gather_
+#' @importFrom tidyr gather
 #' 
 #' @examples
 #' \dontrun{
@@ -140,7 +140,7 @@ plot.gg_interaction <- function(x, xvar, lbls, ...){
     gg_dta$rank <- 1:dim(gg_dta)[1]
     
     gathercols <- colnames(gg_dta)[-which(colnames(gg_dta) %in% c("rank", "names"))]
-    gg_dta <- tidyr::gather_(gg_dta, "variable", "value", gathercols)
+    gg_dta <- tidyr::gather(gg_dta, "variable", "value", gathercols)
     
     gg_dta$value <- as.numeric(gg_dta$value)
     gg_dta$names <- factor(gg_dta$names,
