@@ -17,11 +17,13 @@
 ####**********************************************************************
 ####**********************************************************************
 #'
-#' Plot a \code{\link{gg_minimal_vimp}} object for comparing the Minimal Depth and VIMP variable rankings.
+#' Plot a \code{\link{gg_minimal_vimp}} object for comparing the Minimal 
+#' Depth and VIMP variable rankings.
 #' 
-#' @param x \code{\link{gg_minimal_depth}} object created from a \code{randomForestSRC::var.select} 
+#' @param x \code{\link{gg_minimal_depth}} object created from a 
+#' \code{\link[randomForestSRC]{var.select}}
 #' object
-#' @param modelsize should the figure be restricted to a subset of the points.
+#' @param nvar should the figure be restricted to a subset of the points.
 #' @param lbls a vector of alternative variable names.
 #' @param ... optional arguments (not used)
 #' 
@@ -30,7 +32,7 @@
 #' 
 #' @importFrom ggplot2 ggplot aes_string geom_point labs geom_abline coord_flip scale_x_discrete
 #'
-#' @seealso \code{\link{gg_minimal_vimp}} \code{randomForestSRC::var.select}
+#' @seealso \code{\link{gg_minimal_vimp}} \code{\link[randomForestSRC]{var.select}}
 #'  
 #' @examples
 #' \dontrun{
@@ -55,10 +57,8 @@
 #' ## Regression example
 #' ## ------------------------------------------------------------
 #' ## -------- air quality data
-#' # rfsrc_airq <- rfsrc(Ozone ~ ., data = airquality, na.action = "na.impute")
-#' # varsel_airq <- var.select(rfsrc_airq)
-#' # ... or load a cached randomForestSRC object
-#' data(varsel_airq, package="ggRandomForests")
+#' rfsrc_airq <- rfsrc(Ozone ~ ., data = airquality, na.action = "na.impute")
+#' varsel_airq <- var.select(rfsrc_airq)
 #' 
 #' # Get a data.frame containing error rates
 #' gg_dta<- gg_minimal_vimp(varsel_airq)
@@ -106,7 +106,7 @@
 #' } 
 #' 
 #' @export 
-plot.gg_minimal_vimp <- function(x, modelsize, lbls, ...){
+plot.gg_minimal_vimp <- function(x, nvar, lbls, ...){
   gg_dta <- x
   
   # Test that object is the correct class object
@@ -114,21 +114,20 @@ plot.gg_minimal_vimp <- function(x, modelsize, lbls, ...){
     gg_dta <- gg_minimal_vimp(x, ...)
   }
   
-  if(missing(modelsize)) modelsize <- dim(gg_dta)[1]
-  if(modelsize > dim(gg_dta)[1]) modelsize <- dim(gg_dta)[1]
+  if(missing(nvar)) nvar <- nrow(gg_dta)
+  if(nvar > nrow(gg_dta)) nvar <- nrow(gg_dta)
   if(length(unique(gg_dta$col)) > 1){
     gg_dta$col <- factor(gg_dta$col)
   }
   gg_dta$names <- factor(gg_dta$names, 
                          levels=gg_dta$names[order(as.numeric(gg_dta$depth))])
   
-  gg_dta <- gg_dta[1:modelsize, ]
+  gg_dta <- gg_dta[1:nvar, ]
   
   # If we only have one class for coloring, just paint them black.
   if(length(unique(gg_dta$col)) > 1){
     gg_plt <- ggplot(gg_dta, aes_string(x="names", y="vimp", col="col")) +
       labs(x="Minimal Depth (Rank Order)", y="VIMP Rank", color="VIMP")
-    
   }else{
     gg_plt <- ggplot(gg_dta, aes_string(x="names", y="vimp")) +
       labs(x="Minimal Depth (Rank Order)", y="VIMP Rank")
@@ -144,7 +143,20 @@ plot.gg_minimal_vimp <- function(x, modelsize, lbls, ...){
     }
   }
   
-  gg_plt + geom_point() +
-    geom_abline(xintercept=0, slope=1, col="red", size=.5, linetype=2) +
-    coord_flip()
+  gg_plt <- gg_plt + geom_point() +
+    geom_abline(intercept=0, slope=1, col="red", size=.5, linetype=2)
+  
+  # Draw a line between + and - vimp values.
+  if(length(unique(gg_dta$col)) > 1){
+    gg_plt <- gg_plt +
+      geom_hline(yintercept=sum(gg_dta$col == "+") + .5, col="red", size=.5, linetype=2)
+  }
+  
+  if(nrow(gg_dta) > attributes(gg_dta)$modelsize){
+    gg_plt <- gg_plt +
+      geom_vline(xintercept=attributes(gg_dta)$modelsize + .5, col="red", size=.5, linetype=2)
+  }
+  
+  gg_plt + coord_flip()
+  
 }
