@@ -2,9 +2,12 @@
 context("gg_vimp tests")
 
 test_that("gg_vimp classifications", {
+  
   ## Load the cached forest
-  data(rfsrc_iris, package="ggRandomForests")
-
+  data(iris, package="datasets")
+  rfsrc_iris <- randomForestSRC::rfsrc(Species ~., 
+                                       data = iris, 
+                                       importance=TRUE, tree.err=TRUE)
   # Test the cached forest type
   expect_is(rfsrc_iris, "rfsrc")
 
@@ -92,9 +95,16 @@ test_that("gg_vimp classifications", {
 
 
 test_that("gg_vimp survival",{
-  ## Load the cached forest
-  data(rfsrc_pbc, package="ggRandomForests")
-
+  
+  pbc <- pbc_data()
+  dta.train <- pbc[-which(is.na(pbc$treatment)),]
+  # Create a test set from the remaining patients
+  pbc.test <- pbc[which(is.na(pbc$treatment)),]
+  
+  rfsrc_pbc <- randomForestSRC::rfsrc(Surv(years, status) ~ ., 
+                                      dta.train, nsplit = 10,
+                                      na.action="na.impute",
+                                      importance=TRUE, tree.err=TRUE)
   # Test the cached forest type
   expect_is(rfsrc_pbc, "rfsrc")
 
@@ -143,9 +153,14 @@ test_that("gg_vimp survival",{
 })
 
 test_that("gg_vimp regression",{
+  
   ## Load the cached forest
-  data(rfsrc_Boston, package="ggRandomForests")
-
+  data(Boston, package="MASS")
+  
+  Boston$chas <- as.logical(Boston$chas)
+  
+  rfsrc_Boston <- randomForestSRC::rfsrc(medv~., data=Boston,
+                                         importance = TRUE)
   # Test the cached forest type
   expect_is(rfsrc_Boston, "rfsrc")
 
@@ -169,7 +184,6 @@ test_that("gg_vimp regression",{
   # Test return is s ggplot object
   expect_is(gg_plt, "ggplot")
 
-  data(Boston, package="MASS")
 
   cls <- sapply(Boston, class)
   #
